@@ -1,11 +1,9 @@
 from cjkcms.models.wagtailsettings_models import AdobeApiSettings
 from cjkcms.settings import cms_settings
 from django.contrib.staticfiles import finders
-from django.contrib.staticfiles.storage import staticfiles_storage
 from django.template.loader import get_template
 from django.test import TestCase
 from wagtail.core.models import Site
-import pytest
 
 # import TemplateDoesNotExist
 from django.template import TemplateDoesNotExist
